@@ -2,6 +2,8 @@
 #include <src/ChannelListWriter.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/collection.h>
+#include <gee/list.h>
 #include "src/Terrestrial/TerrestrialChannel.h"
 #include "src/Utils.h"
 #include "src/MpegTsEnums.h"
@@ -11,6 +13,7 @@
 
 
 
+static char* string_substring (const char* self, glong offset, glong len);
 struct _DVBChannelListWriterPrivate {
 	GFile* _file;
 	GOutputStream* stream;
@@ -33,6 +36,26 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 
 
 
+static char* string_substring (const char* self, glong offset, glong len) {
+	glong string_length;
+	const char* start;
+	g_return_val_if_fail (self != NULL, NULL);
+	string_length = g_utf8_strlen (self, -1);
+	if (offset < 0) {
+		offset = string_length + offset;
+		g_return_val_if_fail (offset >= 0, NULL);
+	} else {
+		g_return_val_if_fail (offset <= string_length, NULL);
+	}
+	if (len < 0) {
+		len = string_length - offset;
+	}
+	g_return_val_if_fail ((offset + len) <= string_length, NULL);
+	start = g_utf8_offset_to_pointer (self, offset);
+	return g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
+}
+
+
 static void dvb_channel_list_writer_open_stream (DVBChannelListWriter* self, GError** error) {
 	GError * inner_error;
 	GFileOutputStream* fostream;
@@ -99,6 +122,7 @@ void dvb_channel_list_writer_write (DVBChannelListWriter* self, DVBChannel* chan
 	GError * inner_error;
 	char* buffer;
 	char* _tmp0;
+	guint apid;
 	char* _tmp1;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (channel != NULL);
@@ -152,9 +176,15 @@ void dvb_channel_list_writer_write (DVBChannelListWriter* self, DVBChannel* chan
 			}
 		}
 	}
+	apid = 0U;
+	if (gee_collection_get_size ((GeeCollection*) dvb_channel_get_AudioPIDs (channel)) == 0) {
+		apid = (guint) 0;
+	} else {
+		apid = GPOINTER_TO_UINT (gee_list_get (dvb_channel_get_AudioPIDs (channel), 0));
+	}
 	/* Write common data*/
 	_tmp1 = NULL;
-	buffer = (_tmp1 = g_strdup_printf (":%u:%u:%u\n", dvb_channel_get_VideoPID (channel), dvb_channel_get_AudioPID (channel), dvb_channel_get_Sid (channel)), buffer = (g_free (buffer), NULL), _tmp1);
+	buffer = (_tmp1 = g_strdup_printf (":%u:%u:%u\n", dvb_channel_get_VideoPID (channel), apid, dvb_channel_get_Sid (channel)), buffer = (g_free (buffer), NULL), _tmp1);
 	g_output_stream_write (self->priv->stream, buffer, (gsize) strlen (buffer), NULL, &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
@@ -182,6 +212,7 @@ gboolean dvb_channel_list_writer_close (DVBChannelListWriter* self, GError** err
 static void dvb_channel_list_writer_write_terrestrial_channel (DVBChannelListWriter* self, DVBTerrestrialChannel* channel, GError** error) {
 	GError * inner_error;
 	char** _tmp0;
+	gint elements_size;
 	gint elements_length1;
 	char** elements;
 	char* _tmp1;
@@ -198,7 +229,7 @@ static void dvb_channel_list_writer_write_terrestrial_channel (DVBChannelListWri
 	g_return_if_fail (channel != NULL);
 	inner_error = NULL;
 	_tmp0 = NULL;
-	elements = (_tmp0 = g_new0 (char*, 9 + 1), elements_length1 = 9, _tmp0);
+	elements = (_tmp0 = g_new0 (char*, 9 + 1), elements_length1 = 9, elements_size = elements_length1, _tmp0);
 	_tmp1 = NULL;
 	elements[0] = (_tmp1 = g_strdup_printf ("%u", dvb_channel_get_Frequency ((DVBChannel*) channel)), elements[0] = (g_free (elements[0]), NULL), _tmp1);
 	_tmp2 = NULL;
@@ -250,6 +281,7 @@ static void dvb_channel_list_writer_write_satellite_channel (DVBChannelListWrite
 static void dvb_channel_list_writer_write_cable_channel (DVBChannelListWriter* self, DVBCableChannel* channel, GError** error) {
 	GError * inner_error;
 	char** _tmp0;
+	gint elements_size;
 	gint elements_length1;
 	char** elements;
 	char* _tmp1;
@@ -262,7 +294,7 @@ static void dvb_channel_list_writer_write_cable_channel (DVBChannelListWriter* s
 	g_return_if_fail (channel != NULL);
 	inner_error = NULL;
 	_tmp0 = NULL;
-	elements = (_tmp0 = g_new0 (char*, 5 + 1), elements_length1 = 5, _tmp0);
+	elements = (_tmp0 = g_new0 (char*, 5 + 1), elements_length1 = 5, elements_size = elements_length1, _tmp0);
 	_tmp1 = NULL;
 	elements[0] = (_tmp1 = g_strdup_printf ("%u", dvb_channel_get_Frequency ((DVBChannel*) channel)), elements[0] = (g_free (elements[0]), NULL), _tmp1);
 	_tmp2 = NULL;
@@ -290,13 +322,11 @@ static char* dvb_channel_list_writer_get_name_without_prefix (GType enumtype, gi
 	const char* _tmp0;
 	char* name;
 	char* _tmp1;
-	char* _tmp2;
 	g_return_val_if_fail (prefix != NULL, NULL);
 	_tmp0 = NULL;
 	name = (_tmp0 = dvb_utils_get_name_by_value_from_enum (enumtype, val), (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
 	_tmp1 = NULL;
-	_tmp2 = NULL;
-	return (_tmp2 = (_tmp1 = g_utf8_offset_to_pointer (name, strlen (prefix)), g_strndup (_tmp1, g_utf8_offset_to_pointer (_tmp1, strlen (name)) - _tmp1)), name = (g_free (name), NULL), _tmp2);
+	return (_tmp1 = string_substring (name, strlen (prefix), strlen (name) - strlen (prefix)), name = (g_free (name), NULL), _tmp1);
 }
 
 
@@ -319,6 +349,7 @@ static void dvb_channel_list_writer_set_file (DVBChannelListWriter* self, GFile*
 
 static void dvb_channel_list_writer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	DVBChannelListWriter * self;
+	gpointer boxed;
 	self = DVB_CHANNEL_LIST_WRITER (object);
 	switch (property_id) {
 		case DVB_CHANNEL_LIST_WRITER_FILE:
@@ -382,14 +413,10 @@ GType dvb_channel_list_writer_get_type (void) {
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
-		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
-		}
-		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) array)[i] != NULL) {
+				destroy_func (((gpointer*) array)[i]);
+			}
 		}
 	}
 	g_free (array);
