@@ -27,7 +27,7 @@ enum  {
 };
 #define DVB_DEVICE_PRIME 31
 static DVBAdapterType dvb_device_getAdapterType (guint adapter, gboolean get_type);
-static const char* dvb_device_getAdapterName (guint adapter, gboolean get_name);
+static char* dvb_device_getAdapterName (guint adapter, gboolean get_name);
 static void dvb_device_set_Adapter (DVBDevice* self, guint value);
 static void dvb_device_set_Frontend (DVBDevice* self, guint value);
 static void dvb_device_set_Type (DVBDevice* self, DVBAdapterType value);
@@ -42,7 +42,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 GType dvb_adapter_type_get_type (void) {
 	static GType dvb_adapter_type_type_id = 0;
 	if (G_UNLIKELY (dvb_adapter_type_type_id == 0)) {
-		static const GEnumValue values[] = {{DVB_ADAPTER_TYPE_DVB_T, "DVB_ADAPTER_TYPE_DVB_T", "dvb-t"}, {DVB_ADAPTER_TYPE_DVB_S, "DVB_ADAPTER_TYPE_DVB_S", "dvb-s"}, {DVB_ADAPTER_TYPE_DVB_C, "DVB_ADAPTER_TYPE_DVB_C", "dvb-c"}, {DVB_ADAPTER_TYPE_UNKNOWN, "DVB_ADAPTER_TYPE_UNKNOWN", "unknown"}, {0, NULL, NULL}};
+		static const GEnumValue values[] = {{DVB_ADAPTER_TYPE_UNKNOWN, "DVB_ADAPTER_TYPE_UNKNOWN", "unknown"}, {DVB_ADAPTER_TYPE_DVB_T, "DVB_ADAPTER_TYPE_DVB_T", "dvb-t"}, {DVB_ADAPTER_TYPE_DVB_S, "DVB_ADAPTER_TYPE_DVB_S", "dvb-s"}, {DVB_ADAPTER_TYPE_DVB_C, "DVB_ADAPTER_TYPE_DVB_C", "dvb-c"}, {0, NULL, NULL}};
 		dvb_adapter_type_type_id = g_enum_register_static ("DVBAdapterType", values);
 	}
 	return dvb_adapter_type_type_id;
@@ -52,6 +52,7 @@ GType dvb_adapter_type_get_type (void) {
 DVBDevice* dvb_device_construct (GType object_type, guint adapter, guint frontend, gboolean get_type_and_name) {
 	GParameter * __params;
 	GParameter * __params_it;
+	char* _tmp0;
 	DVBDevice * self;
 	__params = g_new0 (GParameter, 4);
 	__params_it = __params;
@@ -67,10 +68,12 @@ DVBDevice* dvb_device_construct (GType object_type, guint adapter, guint fronten
 	g_value_init (&__params_it->value, DVB_TYPE_ADAPTER_TYPE);
 	g_value_set_enum (&__params_it->value, dvb_device_getAdapterType (adapter, get_type_and_name));
 	__params_it++;
+	_tmp0 = NULL;
 	__params_it->name = "Name";
 	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, dvb_device_getAdapterName (adapter, get_type_and_name));
+	g_value_set_string (&__params_it->value, _tmp0 = dvb_device_getAdapterName (adapter, get_type_and_name));
 	__params_it++;
+	_tmp0 = (g_free (_tmp0), NULL);
 	self = g_object_newv (object_type, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
@@ -88,8 +91,8 @@ DVBDevice* dvb_device_new (guint adapter, guint frontend, gboolean get_type_and_
 
 DVBDevice* dvb_device_new_full (guint adapter, guint frontend, DVBChannelList* channels, GFile* recordings_dir) {
 	DVBDevice* dev;
-	g_return_val_if_fail (DVB_IS_CHANNEL_LIST (channels), NULL);
-	g_return_val_if_fail (G_IS_FILE (recordings_dir), NULL);
+	g_return_val_if_fail (channels != NULL, NULL);
+	g_return_val_if_fail (recordings_dir != NULL, NULL);
 	dev = dvb_device_new (adapter, frontend, TRUE);
 	dvb_device_set_Channels (dev, channels);
 	dvb_device_set_RecordingsDirectory (dev, recordings_dir);
@@ -98,243 +101,303 @@ DVBDevice* dvb_device_new_full (guint adapter, guint frontend, DVBChannelList* c
 
 
 gboolean dvb_device_equal (DVBDevice* dev1, DVBDevice* dev2) {
-	if (dev1 == NULL || dev2 == NULL) {
+	gboolean _tmp0;
+	gboolean _tmp2;
+	_tmp0 = FALSE;
+	if (dev1 == NULL) {
+		_tmp0 = TRUE;
+	} else {
+		_tmp0 = dev2 == NULL;
+	}
+	if (_tmp0) {
 		return FALSE;
 	}
-	return (DVB_DEVICE (dev1)->priv->_Adapter == DVB_DEVICE (dev2)->priv->_Adapter && DVB_DEVICE (dev2)->priv->_Frontend == DVB_DEVICE (dev2)->priv->_Frontend);
+	_tmp2 = FALSE;
+	if (dev1->priv->_Adapter == dev2->priv->_Adapter) {
+		_tmp2 = dev2->priv->_Frontend == dev2->priv->_Frontend;
+	} else {
+		_tmp2 = FALSE;
+	}
+	return (_tmp2);
 }
 
 
 guint dvb_device_hash (DVBDevice* device) {
 	if (device == NULL) {
-		return ((guint) (0));
+		return (guint) 0;
 	}
-	return dvb_device_hash_without_device (DVB_DEVICE (device)->priv->_Adapter, DVB_DEVICE (device)->priv->_Frontend);
+	return dvb_device_hash_without_device (device->priv->_Adapter, device->priv->_Frontend);
 }
 
 
 guint dvb_device_hash_without_device (guint adapter, guint frontend) {
-	return 2 * DVB_DEVICE_PRIME + DVB_DEVICE_PRIME * adapter + frontend;
+	return ((2 * DVB_DEVICE_PRIME) + (DVB_DEVICE_PRIME * adapter)) + frontend;
 }
 
 
 gboolean dvb_device_is_busy (DVBDevice* self) {
 	GstElement* dvbsrc;
 	GstElement* pipeline;
-	GstElement* _tmp0;
+	GstElement* _tmp1;
 	GstBus* bus;
 	gboolean busy_val;
-	gboolean _tmp5;
-	g_return_val_if_fail (DVB_IS_DEVICE (self), FALSE);
+	gboolean _tmp7;
+	g_return_val_if_fail (self != NULL, FALSE);
 	dvbsrc = gst_element_factory_make ("dvbsrc", "text_dvbsrc");
-	g_object_set (G_OBJECT (dvbsrc), "adapter", self->priv->_Adapter, NULL);
-	g_object_set (G_OBJECT (dvbsrc), "frontend", self->priv->_Frontend, NULL);
-	pipeline = GST_ELEMENT (((GstPipeline*) (gst_pipeline_new (""))));
-	_tmp0 = NULL;
-	gst_bin_add ((GST_BIN (pipeline)), (_tmp0 = dvbsrc, (_tmp0 == NULL ? NULL : gst_object_ref (_tmp0))));
+	if (dvbsrc == NULL) {
+		gboolean _tmp0;
+		g_critical ("Device.vala:60: Could not create dvbsrc element");
+		return (_tmp0 = TRUE, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), _tmp0);
+	}
+	g_object_set ((GObject*) dvbsrc, "adapter", self->priv->_Adapter, NULL);
+	g_object_set ((GObject*) dvbsrc, "frontend", self->priv->_Frontend, NULL);
+	pipeline = (GstElement*) ((GstPipeline*) gst_pipeline_new (""));
+	_tmp1 = NULL;
+	gst_bin_add ((GST_BIN (pipeline)), (_tmp1 = dvbsrc, (_tmp1 == NULL) ? NULL : gst_object_ref (_tmp1)));
 	gst_element_set_state (pipeline, GST_STATE_READY);
 	bus = gst_element_get_bus (pipeline);
 	busy_val = FALSE;
 	while (gst_bus_have_pending (bus)) {
 		GstMessage* msg;
+		gboolean _tmp2;
 		msg = gst_bus_pop (bus);
-		if (msg->type == GST_MESSAGE_ERROR && msg->src == GST_OBJECT (dvbsrc)) {
+		_tmp2 = FALSE;
+		if (msg->type == GST_MESSAGE_ERROR) {
+			_tmp2 = msg->src == GST_OBJECT (dvbsrc);
+		} else {
+			_tmp2 = FALSE;
+		}
+		if (_tmp2) {
 			GError* gerror;
 			char* debug_text;
-			char* _tmp4;
-			char* _tmp3;
-			GError* _tmp2;
-			GError* _tmp1;
+			char* _tmp6;
+			char* _tmp5;
+			GError* _tmp4;
+			GError* _tmp3;
 			gerror = NULL;
 			debug_text = NULL;
+			_tmp6 = NULL;
+			_tmp5 = NULL;
 			_tmp4 = NULL;
 			_tmp3 = NULL;
-			_tmp2 = NULL;
-			_tmp1 = NULL;
-			(gst_message_parse_error (msg, &_tmp1, &_tmp3), gerror = (_tmp2 = _tmp1, (gerror == NULL ? NULL : (gerror = (g_error_free (gerror), NULL))), _tmp2));
-			debug_text = (_tmp4 = _tmp3, (debug_text = (g_free (debug_text), NULL)), _tmp4);
-			g_debug (gerror->message);
-			g_debug (debug_text);
+			(gst_message_parse_error (msg, &_tmp3, &_tmp5), gerror = (_tmp4 = _tmp3, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp4));
+			debug_text = (_tmp6 = _tmp5, debug_text = (g_free (debug_text), NULL), _tmp6);
+			g_debug ("Device.vala:82: Error tuning: %s; %s", gerror->message, debug_text);
 			busy_val = TRUE;
-			(gerror == NULL ? NULL : (gerror = (g_error_free (gerror), NULL)));
+			(gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL));
 			debug_text = (g_free (debug_text), NULL);
 		}
+		(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
 	}
 	gst_element_set_state (pipeline, GST_STATE_NULL);
-	return (_tmp5 = busy_val, (dvbsrc == NULL ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL))), (pipeline == NULL ? NULL : (pipeline = (gst_object_unref (pipeline), NULL))), (bus == NULL ? NULL : (bus = (gst_object_unref (bus), NULL))), _tmp5);
+	return (_tmp7 = busy_val, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), _tmp7);
 }
 
 
 static DVBAdapterType dvb_device_getAdapterType (guint adapter, gboolean get_type) {
 	GstElement* dvbsrc;
 	GstElement* pipeline;
-	GstElement* _tmp1;
+	GstElement* _tmp2;
 	GstBus* bus;
-	const char* adapter_type;
+	char* adapter_type;
 	if (!get_type) {
 		return DVB_ADAPTER_TYPE_UNKNOWN;
 	}
 	dvbsrc = gst_element_factory_make ("dvbsrc", "test_dvbsrc");
-	g_object_set (G_OBJECT (dvbsrc), "adapter", adapter, NULL);
-	pipeline = GST_ELEMENT (((GstPipeline*) (gst_pipeline_new (""))));
-	_tmp1 = NULL;
-	gst_bin_add ((GST_BIN (pipeline)), (_tmp1 = dvbsrc, (_tmp1 == NULL ? NULL : gst_object_ref (_tmp1))));
+	if (dvbsrc == NULL) {
+		DVBAdapterType _tmp1;
+		g_critical ("Device.vala:98: Could not create dvbsrc element");
+		return (_tmp1 = DVB_ADAPTER_TYPE_UNKNOWN, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), _tmp1);
+	}
+	g_object_set ((GObject*) dvbsrc, "adapter", adapter, NULL);
+	pipeline = (GstElement*) ((GstPipeline*) gst_pipeline_new (""));
+	_tmp2 = NULL;
+	gst_bin_add ((GST_BIN (pipeline)), (_tmp2 = dvbsrc, (_tmp2 == NULL) ? NULL : gst_object_ref (_tmp2)));
 	gst_element_set_state (pipeline, GST_STATE_READY);
 	bus = gst_element_get_bus (pipeline);
 	adapter_type = NULL;
 	while (gst_bus_have_pending (bus)) {
 		GstMessage* msg;
+		gboolean _tmp3;
 		msg = gst_bus_pop (bus);
-		if (msg->type == GST_MESSAGE_ELEMENT && msg->src == GST_OBJECT (dvbsrc)) {
+		_tmp3 = FALSE;
+		if (msg->type == GST_MESSAGE_ELEMENT) {
+			_tmp3 = msg->src == GST_OBJECT (dvbsrc);
+		} else {
+			_tmp3 = FALSE;
+		}
+		if (_tmp3) {
 			const GstStructure* structure;
 			structure = msg->structure;
 			if (_vala_strcmp0 (gst_structure_get_name (structure), "dvb-adapter") == 0) {
-				adapter_type = gst_structure_get_string (structure, "type");
+				char* _tmp4;
+				_tmp4 = NULL;
+				adapter_type = (_tmp4 = g_strdup_printf ("%s", gst_structure_get_string (structure, "type")), adapter_type = (g_free (adapter_type), NULL), _tmp4);
+				(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
 				break;
 			}
 		} else {
 			if (msg->type == GST_MESSAGE_ERROR) {
 				GError* gerror;
 				char* debug;
-				char* _tmp5;
-				char* _tmp4;
-				GError* _tmp3;
-				GError* _tmp2;
+				char* _tmp8;
+				char* _tmp7;
+				GError* _tmp6;
+				GError* _tmp5;
 				gerror = NULL;
 				debug = NULL;
+				_tmp8 = NULL;
+				_tmp7 = NULL;
+				_tmp6 = NULL;
 				_tmp5 = NULL;
-				_tmp4 = NULL;
-				_tmp3 = NULL;
-				_tmp2 = NULL;
-				(gst_message_parse_error (msg, &_tmp2, &_tmp4), gerror = (_tmp3 = _tmp2, (gerror == NULL ? NULL : (gerror = (g_error_free (gerror), NULL))), _tmp3));
-				debug = (_tmp5 = _tmp4, (debug = (g_free (debug), NULL)), _tmp5);
-				g_critical ("Device.vala:118: %s %s", gerror->message, debug);
-				(gerror == NULL ? NULL : (gerror = (g_error_free (gerror), NULL)));
+				(gst_message_parse_error (msg, &_tmp5, &_tmp7), gerror = (_tmp6 = _tmp5, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp6));
+				debug = (_tmp8 = _tmp7, debug = (g_free (debug), NULL), _tmp8);
+				g_critical ("Device.vala:125: %s %s", gerror->message, debug);
+				(gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL));
 				debug = (g_free (debug), NULL);
 			}
 		}
+		(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
 	}
 	gst_element_set_state (pipeline, GST_STATE_NULL);
 	if (_vala_strcmp0 (adapter_type, "DVB-T") == 0) {
-		DVBAdapterType _tmp6;
-		return (_tmp6 = DVB_ADAPTER_TYPE_DVB_T, (dvbsrc == NULL ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL))), (pipeline == NULL ? NULL : (pipeline = (gst_object_unref (pipeline), NULL))), (bus == NULL ? NULL : (bus = (gst_object_unref (bus), NULL))), _tmp6);
+		DVBAdapterType _tmp9;
+		return (_tmp9 = DVB_ADAPTER_TYPE_DVB_T, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp9);
 	} else {
 		if (_vala_strcmp0 (adapter_type, "DVB-S") == 0) {
-			DVBAdapterType _tmp7;
-			return (_tmp7 = DVB_ADAPTER_TYPE_DVB_S, (dvbsrc == NULL ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL))), (pipeline == NULL ? NULL : (pipeline = (gst_object_unref (pipeline), NULL))), (bus == NULL ? NULL : (bus = (gst_object_unref (bus), NULL))), _tmp7);
+			DVBAdapterType _tmp10;
+			return (_tmp10 = DVB_ADAPTER_TYPE_DVB_S, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp10);
 		} else {
 			if (_vala_strcmp0 (adapter_type, "DVB-C") == 0) {
-				DVBAdapterType _tmp8;
-				return (_tmp8 = DVB_ADAPTER_TYPE_DVB_C, (dvbsrc == NULL ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL))), (pipeline == NULL ? NULL : (pipeline = (gst_object_unref (pipeline), NULL))), (bus == NULL ? NULL : (bus = (gst_object_unref (bus), NULL))), _tmp8);
+				DVBAdapterType _tmp11;
+				return (_tmp11 = DVB_ADAPTER_TYPE_DVB_C, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp11);
 			} else {
-				DVBAdapterType _tmp9;
-				return (_tmp9 = DVB_ADAPTER_TYPE_UNKNOWN, (dvbsrc == NULL ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL))), (pipeline == NULL ? NULL : (pipeline = (gst_object_unref (pipeline), NULL))), (bus == NULL ? NULL : (bus = (gst_object_unref (bus), NULL))), _tmp9);
+				DVBAdapterType _tmp12;
+				return (_tmp12 = DVB_ADAPTER_TYPE_UNKNOWN, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp12);
 			}
 		}
 	}
-	(dvbsrc == NULL ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)));
-	(pipeline == NULL ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)));
-	(bus == NULL ? NULL : (bus = (gst_object_unref (bus), NULL)));
+	(dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL));
+	(pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL));
+	(bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL));
+	adapter_type = (g_free (adapter_type), NULL);
 }
 
 
-static const char* dvb_device_getAdapterName (guint adapter, gboolean get_name) {
+static char* dvb_device_getAdapterName (guint adapter, gboolean get_name) {
 	GstElement* dvbsrc;
 	GstElement* pipeline;
-	GstElement* _tmp1;
+	GstElement* _tmp2;
 	GstBus* bus;
-	const char* adapter_name;
-	char* _tmp6;
+	char* adapter_name;
+	char* _tmp9;
 	if (!get_name) {
 		return NULL;
 	}
 	dvbsrc = gst_element_factory_make ("dvbsrc", "test_dvbsrc");
-	g_object_set (G_OBJECT (dvbsrc), "adapter", adapter, NULL);
-	pipeline = GST_ELEMENT (((GstPipeline*) (gst_pipeline_new (""))));
-	_tmp1 = NULL;
-	gst_bin_add ((GST_BIN (pipeline)), (_tmp1 = dvbsrc, (_tmp1 == NULL ? NULL : gst_object_ref (_tmp1))));
+	if (dvbsrc == NULL) {
+		char* _tmp1;
+		g_critical ("Device.vala:142: Could not create dvbsrc element");
+		_tmp1 = NULL;
+		return (_tmp1 = NULL, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), _tmp1);
+	}
+	g_object_set ((GObject*) dvbsrc, "adapter", adapter, NULL);
+	pipeline = (GstElement*) ((GstPipeline*) gst_pipeline_new (""));
+	_tmp2 = NULL;
+	gst_bin_add ((GST_BIN (pipeline)), (_tmp2 = dvbsrc, (_tmp2 == NULL) ? NULL : gst_object_ref (_tmp2)));
 	gst_element_set_state (pipeline, GST_STATE_READY);
 	bus = gst_element_get_bus (pipeline);
 	adapter_name = NULL;
 	while (gst_bus_have_pending (bus)) {
 		GstMessage* msg;
+		gboolean _tmp3;
 		msg = gst_bus_pop (bus);
-		if (msg->type == GST_MESSAGE_ELEMENT && msg->src == GST_OBJECT (dvbsrc)) {
+		_tmp3 = FALSE;
+		if (msg->type == GST_MESSAGE_ELEMENT) {
+			_tmp3 = msg->src == GST_OBJECT (dvbsrc);
+		} else {
+			_tmp3 = FALSE;
+		}
+		if (_tmp3) {
 			const GstStructure* structure;
 			structure = msg->structure;
 			if (_vala_strcmp0 (gst_structure_get_name (structure), "dvb-adapter") == 0) {
-				adapter_name = gst_structure_get_string (structure, "name");
+				char* _tmp4;
+				_tmp4 = NULL;
+				adapter_name = (_tmp4 = g_strdup_printf ("%s", gst_structure_get_string (structure, "name")), adapter_name = (g_free (adapter_name), NULL), _tmp4);
+				(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
 				break;
 			}
 		} else {
 			if (msg->type == GST_MESSAGE_ERROR) {
 				GError* gerror;
 				char* debug;
-				char* _tmp5;
-				char* _tmp4;
-				GError* _tmp3;
-				GError* _tmp2;
+				char* _tmp8;
+				char* _tmp7;
+				GError* _tmp6;
+				GError* _tmp5;
 				gerror = NULL;
 				debug = NULL;
+				_tmp8 = NULL;
+				_tmp7 = NULL;
+				_tmp6 = NULL;
 				_tmp5 = NULL;
-				_tmp4 = NULL;
-				_tmp3 = NULL;
-				_tmp2 = NULL;
-				(gst_message_parse_error (msg, &_tmp2, &_tmp4), gerror = (_tmp3 = _tmp2, (gerror == NULL ? NULL : (gerror = (g_error_free (gerror), NULL))), _tmp3));
-				debug = (_tmp5 = _tmp4, (debug = (g_free (debug), NULL)), _tmp5);
-				g_critical ("Device.vala:158: %s %s", gerror->message, debug);
-				(gerror == NULL ? NULL : (gerror = (g_error_free (gerror), NULL)));
+				(gst_message_parse_error (msg, &_tmp5, &_tmp7), gerror = (_tmp6 = _tmp5, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp6));
+				debug = (_tmp8 = _tmp7, debug = (g_free (debug), NULL), _tmp8);
+				g_critical ("Device.vala:169: %s %s", gerror->message, debug);
+				(gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL));
 				debug = (g_free (debug), NULL);
 			}
 		}
+		(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
 	}
 	gst_element_set_state (pipeline, GST_STATE_NULL);
-	_tmp6 = NULL;
-	return (_tmp6 = adapter_name, (dvbsrc == NULL ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL))), (pipeline == NULL ? NULL : (pipeline = (gst_object_unref (pipeline), NULL))), (bus == NULL ? NULL : (bus = (gst_object_unref (bus), NULL))), _tmp6);
+	_tmp9 = NULL;
+	return (_tmp9 = adapter_name, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), _tmp9);
 }
 
 
 guint dvb_device_get_Adapter (DVBDevice* self) {
-	g_return_val_if_fail (DVB_IS_DEVICE (self), 0U);
+	g_return_val_if_fail (self != NULL, 0U);
 	return self->priv->_Adapter;
 }
 
 
 static void dvb_device_set_Adapter (DVBDevice* self, guint value) {
-	g_return_if_fail (DVB_IS_DEVICE (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_Adapter = value;
-	g_object_notify (((GObject *) (self)), "Adapter");
+	g_object_notify ((GObject *) self, "Adapter");
 }
 
 
 guint dvb_device_get_Frontend (DVBDevice* self) {
-	g_return_val_if_fail (DVB_IS_DEVICE (self), 0U);
+	g_return_val_if_fail (self != NULL, 0U);
 	return self->priv->_Frontend;
 }
 
 
 static void dvb_device_set_Frontend (DVBDevice* self, guint value) {
-	g_return_if_fail (DVB_IS_DEVICE (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_Frontend = value;
-	g_object_notify (((GObject *) (self)), "Frontend");
+	g_object_notify ((GObject *) self, "Frontend");
 }
 
 
 DVBAdapterType dvb_device_get_Type (DVBDevice* self) {
-	g_return_val_if_fail (DVB_IS_DEVICE (self), 0);
+	g_return_val_if_fail (self != NULL, 0);
 	return self->priv->_Type;
 }
 
 
 static void dvb_device_set_Type (DVBDevice* self, DVBAdapterType value) {
-	g_return_if_fail (DVB_IS_DEVICE (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_Type = value;
-	g_object_notify (((GObject *) (self)), "Type");
+	g_object_notify ((GObject *) self, "Type");
 }
 
 
 const char* dvb_device_get_Name (DVBDevice* self) {
-	g_return_val_if_fail (DVB_IS_DEVICE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_Name;
 }
 
@@ -342,16 +405,16 @@ const char* dvb_device_get_Name (DVBDevice* self) {
 static void dvb_device_set_Name (DVBDevice* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
-	g_return_if_fail (DVB_IS_DEVICE (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_Name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_Name = (g_free (self->priv->_Name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "Name");
+	self->priv->_Name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_Name = (g_free (self->priv->_Name), NULL), _tmp2);
+	g_object_notify ((GObject *) self, "Name");
 }
 
 
 DVBChannelList* dvb_device_get_Channels (DVBDevice* self) {
-	g_return_val_if_fail (DVB_IS_DEVICE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_Channels;
 }
 
@@ -359,16 +422,16 @@ DVBChannelList* dvb_device_get_Channels (DVBDevice* self) {
 void dvb_device_set_Channels (DVBDevice* self, DVBChannelList* value) {
 	DVBChannelList* _tmp2;
 	DVBChannelList* _tmp1;
-	g_return_if_fail (DVB_IS_DEVICE (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_Channels = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_Channels == NULL ? NULL : (self->priv->_Channels = (g_object_unref (self->priv->_Channels), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "Channels");
+	self->priv->_Channels = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_Channels == NULL) ? NULL : (self->priv->_Channels = (g_object_unref (self->priv->_Channels), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "Channels");
 }
 
 
 GFile* dvb_device_get_RecordingsDirectory (DVBDevice* self) {
-	g_return_val_if_fail (DVB_IS_DEVICE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_RecordingsDirectory;
 }
 
@@ -376,16 +439,17 @@ GFile* dvb_device_get_RecordingsDirectory (DVBDevice* self) {
 void dvb_device_set_RecordingsDirectory (DVBDevice* self, GFile* value) {
 	GFile* _tmp2;
 	GFile* _tmp1;
-	g_return_if_fail (DVB_IS_DEVICE (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_RecordingsDirectory = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_RecordingsDirectory == NULL ? NULL : (self->priv->_RecordingsDirectory = (g_object_unref (self->priv->_RecordingsDirectory), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "RecordingsDirectory");
+	self->priv->_RecordingsDirectory = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_RecordingsDirectory == NULL) ? NULL : (self->priv->_RecordingsDirectory = (g_object_unref (self->priv->_RecordingsDirectory), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "RecordingsDirectory");
 }
 
 
 static void dvb_device_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	DVBDevice * self;
+	gpointer boxed;
 	self = DVB_DEVICE (object);
 	switch (property_id) {
 		case DVB_DEVICE_ADAPTER:
@@ -466,8 +530,8 @@ static void dvb_device_finalize (GObject* obj) {
 	DVBDevice * self;
 	self = DVB_DEVICE (obj);
 	self->priv->_Name = (g_free (self->priv->_Name), NULL);
-	(self->priv->_Channels == NULL ? NULL : (self->priv->_Channels = (g_object_unref (self->priv->_Channels), NULL)));
-	(self->priv->_RecordingsDirectory == NULL ? NULL : (self->priv->_RecordingsDirectory = (g_object_unref (self->priv->_RecordingsDirectory), NULL)));
+	(self->priv->_Channels == NULL) ? NULL : (self->priv->_Channels = (g_object_unref (self->priv->_Channels), NULL));
+	(self->priv->_RecordingsDirectory == NULL) ? NULL : (self->priv->_RecordingsDirectory = (g_object_unref (self->priv->_RecordingsDirectory), NULL));
 	G_OBJECT_CLASS (dvb_device_parent_class)->finalize (obj);
 }
 
@@ -487,7 +551,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2) {
 		return -(str1 != str2);
 	}
 	if (str2 == NULL) {
-		return (str1 != str2);
+		return str1 != str2;
 	}
 	return strcmp (str1, str2);
 }
