@@ -4,11 +4,12 @@
 #include <stdlib.h>
 #include <string.h>
 #include <gee/hashset.h>
+#include <gee/iterable.h>
 #include <gee/iterator.h>
 #include <gee/collection.h>
 #include "src/Channel.h"
-#include "src/ChannelList.h"
 #include "src/Device.h"
+#include "src/ChannelList.h"
 #include "src/Event.h"
 #include "src/Schedule.h"
 
@@ -22,6 +23,7 @@ struct _DVBEPGScannerPrivate {
 	GQueue* channels;
 	guint scan_event_id;
 	guint queue_scan_event_id;
+	gboolean do_stop;
 };
 
 #define DVB_EPG_SCANNER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DVB_TYPE_EPG_SCANNER, DVBEPGScannerPrivate))
@@ -32,6 +34,7 @@ enum  {
 #define DVB_EPG_SCANNER_CHECK_EIT_INTERVAL 15 * 60
 #define DVB_EPG_SCANNER_WAIT_FOR_EIT_DURATION 10
 #define DVB_EPG_SCANNER_PIPELINE_TEMPLATE "dvbsrc name=dvbsrc adapter=%u frontend=%u pids=0:16:17:18 stats-reporting-interval=0 ! mpegtsparse ! fakesink silent=true"
+static void dvb_epg_scanner_remove_timeouts (DVBEPGScanner* self);
 static void dvb_epg_scanner_reset (DVBEPGScanner* self);
 static void _dvb_epg_scanner_bus_watch_func_gst_bus_message (GstBus* _sender, GstMessage* message, gpointer self);
 static gboolean _dvb_epg_scanner_scan_new_frequency_gsource_func (gpointer self);
@@ -68,7 +71,14 @@ DVBEPGScanner* dvb_epg_scanner_new (DVBDeviceGroup* device) {
          */
 void dvb_epg_scanner_stop (DVBEPGScanner* self) {
 	g_return_if_fail (self != NULL);
-	g_debug ("EPGScanner.vala:40: Stopping EPG scan for group %u", dvb_device_group_get_Id (self->priv->_DeviceGroup));
+	g_debug ("EPGScanner.vala:42: Stopping EPG scan for group %u", dvb_device_group_get_Id (self->priv->_DeviceGroup));
+	dvb_epg_scanner_remove_timeouts (self);
+	dvb_epg_scanner_reset (self);
+}
+
+
+static void dvb_epg_scanner_remove_timeouts (DVBEPGScanner* self) {
+	g_return_if_fail (self != NULL);
 	/* Remove timed scans */
 	if (self->priv->scan_event_id != 0) {
 		g_source_remove (self->priv->scan_event_id);
@@ -78,7 +88,15 @@ void dvb_epg_scanner_stop (DVBEPGScanner* self) {
 		g_source_remove (self->priv->queue_scan_event_id);
 		self->priv->queue_scan_event_id = (guint) 0;
 	}
-	dvb_epg_scanner_reset (self);
+}
+
+
+void dvb_epg_scanner_destroy (DVBEPGScanner* self) {
+	g_return_if_fail (self != NULL);
+	dvb_epg_scanner_remove_timeouts (self);
+	/* Don't call reset directly here
+	             or we get in a in-consistent state */
+	self->priv->do_stop = TRUE;
 }
 
 
@@ -131,7 +149,7 @@ gboolean dvb_epg_scanner_start (DVBEPGScanner* self) {
 	gboolean _tmp7;
 	g_return_val_if_fail (self != NULL, FALSE);
 	inner_error = NULL;
-	g_debug ("EPGScanner.vala:77: Starting EPG scan for group %u", dvb_device_group_get_Id (self->priv->_DeviceGroup));
+	g_debug ("EPGScanner.vala:90: Starting EPG scan for group %u", dvb_device_group_get_Id (self->priv->_DeviceGroup));
 	/* TODO scan all channels?*/
 	unique_frequencies = gee_hash_set_new (G_TYPE_UINT, NULL, NULL, g_direct_hash, g_direct_equal);
 	{
@@ -183,7 +201,7 @@ gboolean dvb_epg_scanner_start (DVBEPGScanner* self) {
 			inner_error = NULL;
 			{
 				gboolean _tmp6;
-				g_error ("EPGScanner.vala:97: Could not create pipeline: %s", e->message);
+				g_error ("EPGScanner.vala:110: Could not create pipeline: %s", e->message);
 				return (_tmp6 = FALSE, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), (unique_frequencies == NULL) ? NULL : (unique_frequencies = (g_object_unref (unique_frequencies), NULL)), (device == NULL) ? NULL : (device = (g_object_unref (device), NULL)), _tmp6);
 			}
 		}
@@ -215,11 +233,18 @@ static gboolean _dvb_epg_scanner_start_gsource_func (gpointer self) {
          * Scan the next frequency for EPG data
          */
 static gboolean dvb_epg_scanner_scan_new_frequency (DVBEPGScanner* self) {
+	gboolean _tmp0;
 	DVBChannel* channel;
-	gboolean _tmp1;
+	gboolean _tmp2;
 	g_return_val_if_fail (self != NULL, FALSE);
+	_tmp0 = FALSE;
 	if (g_queue_is_empty (self->priv->channels)) {
-		g_debug ("EPGScanner.vala:117: Finished EPG scan for group %u", dvb_device_group_get_Id (self->priv->_DeviceGroup));
+		_tmp0 = TRUE;
+	} else {
+		_tmp0 = self->priv->do_stop;
+	}
+	if (_tmp0) {
+		g_debug ("EPGScanner.vala:130: Finished EPG scan for group %u", dvb_device_group_get_Id (self->priv->_DeviceGroup));
 		dvb_epg_scanner_reset (self);
 		/* Time the next iteration*/
 		self->priv->queue_scan_event_id = g_timeout_add_seconds ((guint) DVB_EPG_SCANNER_CHECK_EIT_INTERVAL, _dvb_epg_scanner_start_gsource_func, self);
@@ -237,7 +262,7 @@ static gboolean dvb_epg_scanner_scan_new_frequency (DVBEPGScanner* self) {
 		(dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL));
 	}
 	g_static_rec_mutex_unlock (&self->priv->__lock_pipeline);
-	return (_tmp1 = TRUE, (channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL)), _tmp1);
+	return (_tmp2 = TRUE, (channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL)), _tmp2);
 }
 
 
@@ -249,7 +274,7 @@ static void dvb_epg_scanner_bus_watch_func (DVBEPGScanner* self, GstBus* bus, Gs
 		case GST_MESSAGE_ELEMENT:
 		{
 			if (_vala_strcmp0 (gst_structure_get_name (message->structure), "dvb-read-failure") == 0) {
-				g_critical ("EPGScanner.vala:146: Could not read from DVB device");
+				g_critical ("EPGScanner.vala:159: Could not read from DVB device");
 				dvb_epg_scanner_stop (self);
 			} else {
 				if (_vala_strcmp0 (gst_structure_get_name (message->structure), "eit") == 0) {
@@ -274,7 +299,7 @@ static void dvb_epg_scanner_bus_watch_func (DVBEPGScanner* self, GstBus* bus, Gs
 			_tmp0 = NULL;
 			(gst_message_parse_error (message, &_tmp0, &_tmp2), gerror = (_tmp1 = _tmp0, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp1));
 			debug = (_tmp3 = _tmp2, debug = (g_free (debug), NULL), _tmp3);
-			g_critical ("EPGScanner.vala:157: %s %s", gerror->message, debug);
+			g_critical ("EPGScanner.vala:170: %s %s", gerror->message, debug);
 			dvb_epg_scanner_stop (self);
 			(gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL));
 			debug = (g_free (debug), NULL);
@@ -327,9 +352,9 @@ void dvb_epg_scanner_on_eit_structure (DVBEPGScanner* self, const GstStructure*
 			val = *gst_value_list_get_value (&events, i);
 			event = gst_value_get_structure (&val);
 			sid = dvb_epg_scanner_get_uint_val (structure, "service-id");
-			channel = dvb_channel_list_get (dvb_device_group_get_Channels (self->priv->_DeviceGroup), sid);
+			channel = dvb_channel_list_get_channel (dvb_device_group_get_Channels (self->priv->_DeviceGroup), sid);
 			if (channel == NULL) {
-				g_warning ("EPGScanner.vala:183: Could not find channel %u for this device", sid);
+				g_warning ("EPGScanner.vala:196: Could not find channel %u for this device", sid);
 				(channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL));
 				return;
 			}
@@ -505,6 +530,7 @@ static GObject * dvb_epg_scanner_constructor (GType type, guint n_construct_prop
 		_tmp0 = NULL;
 		self->priv->channels = (_tmp0 = g_queue_new (), (self->priv->channels == NULL) ? NULL : (self->priv->channels = (g_queue_free (self->priv->channels), NULL)), _tmp0);
 		self->priv->scan_event_id = (guint) 0;
+		self->priv->do_stop = FALSE;
 	}
 	return obj;
 }
